@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -228,7 +228,6 @@ typedef struct _GlobalClosure
    int  logFileStamped; /* time stamp written to log file */
    char *binDir;        /* place where the binary resides */
    char *docDir;        /* place where our documentation resides */
-   char *viewer;        /* Name of preferred PDF viewer */
 
    GMutex progressLock; /* A mutex protected the stuff below */
    char bs[256];        /* A string of 255 backspace characters */
@@ -437,10 +436,10 @@ typedef struct _CrcBlock
  *** forward declarations
  ***/
 
-struct _RawBuffer *rawbuffer_forward;
-struct _DefectiveSectorHeader *dsh_forward;
-struct _DeviceHandle *dh_forward;
-struct _Image *dh_image;
+extern struct _RawBuffer *rawbuffer_forward;
+extern struct _DefectiveSectorHeader *dsh_forward;
+extern struct _DeviceHandle *dh_forward;
+extern struct _Image *dh_image;
 
 /***
  *** bitmap.c
@@ -463,7 +462,7 @@ void FreeBitmap(Bitmap*);
  *** build.h
  ***/
 
-int buildCount;
+extern int buildCount;
 
 /***
  *** cacheprobe.h
@@ -1346,7 +1345,7 @@ int ProbeAltiVec(void);
  *** show-manual.c
  ***/
 
-void ShowPDF(char*);
+void ShowURL(char*);
 
 /***
  *** smart-lec.c
