@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -38,7 +38,7 @@ void register_rs02(void)
 
    /*** Standard infomation and methods */ 
 
-   strncpy(method->name, "RS02", 4);
+   memcpy(method->name, "RS02", 4);
    method->menuEntry = g_strdup(_("Augmented image (RS02)"));
    method->description = g_strdup(_("Reed-Solomon method with improved tolerance for defective ecc data"));
    method->create  = RS02Create;
