@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -21,8 +21,7 @@
  */
 
 #include "dvdisaster.h"
-
-#include "help-dialogs.h"
+#include "build.h"
 
 /***
  *** Online help system for the preferences
@@ -563,13 +562,6 @@ GtkWidget* ShowTextfile(char *title, char *explanation, char *file,
  * About dialog
  */
 
-static void show_modifying(void)
-{  ShowTextfile(_("windowtitle|Modifying dvdisaster"), 
-	       _("<big>Modifying dvdisaster</big>\n"
-		 "<i>Your changes are not ours.</i>"),
-	       "README.MODIFYING", NULL, NULL);
-}
-
 static gint about_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 {  GtkWidget *lab = GTK_BIN(widget)->child;
    char *label = (char*)data;
@@ -581,8 +573,7 @@ static gint about_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
    {  case GDK_BUTTON_PRESS: 
         if(!inside) return FALSE; /* Defect in certain Gtk versions? */
         if(!strcmp(label,"GPL")) ShowGPL(); 
-        else if(!strcmp(label,"MODIFYING")) show_modifying(); 
-        else ShowPDF(g_strdup(label));
+        else ShowURL(g_strdup(label));
 	break; 
       case GDK_ENTER_NOTIFY: 
 	g_sprintf(text, "<span underline=\"single\" color=\"blue\">%s</span>", label);
@@ -699,9 +690,7 @@ void AboutTextWithLink(GtkWidget *parent, char *text, char *action)
 void AboutDialog()
 {  GtkWidget *about, *vbox, *sep;
    char *text; 
-#ifndef MODIFIED_SOURCE
-   const char *lang;
-#endif
+
    /* Create the dialog */
 
    about = gtk_dialog_new_with_buttons(_utf("windowtitle|About dvdisaster"), 
@@ -722,14 +711,7 @@ void AboutDialog()
    AboutText(vbox, text);
    g_free(text);
 
-#ifdef MODIFIED_SOURCE
-   AboutTextWithLink(vbox, 
-		     _("Modified version Copyright 2017 (please fill in - [directions])\n"
-		       "Copyright 2004-2017 Carsten Gnoerlich"),
-		     "MODIFYING");
-#else
-   AboutText(vbox, _("Copyright 2004-2017 Carsten Gnoerlich"));
-#endif
+   AboutText(vbox, _("Copyright 2004-2017 Carsten Gnoerlich.\nCopyright 2019-2021 The dvdisaster development team."));
 
    sep = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 10);
@@ -745,27 +727,16 @@ void AboutDialog()
 				"under the conditions of the [GNU General Public License].\n"), 
 			"GPL");
 
-#ifdef MODIFIED_SOURCE
-   AboutTextWithLink(vbox, _("\nThis program is <b>not the original</b>. It is based on the\n"
-			     "source code of dvdisaster, but contains third-party changes.\n\n"
-			     "Please do not bother the original authors of dvdisaster\n"
-			     "([www.dvdisaster.org]) about issues with this version.\n"),
-		             "http://www.dvdisaster.org");
+   AboutText(vbox, _("\ne-mail: support@dvdisaster.org")); 
 
-#else
-   lang = g_getenv("LANG");
-   if(lang && !strncmp(lang, "de", 2))
-   {    AboutTextWithLink(vbox, "\n[http://www.dvdisaster.de]", "http://www.dvdisaster.de");
-   }
-   else 
-   {    AboutTextWithLink(vbox, "\n[http://www.dvdisaster.com]", "http://www.dvdisaster.com");
-   }
-
-   AboutText(vbox, _("\ne-mail: carsten@dvdisaster.org   -or-   cgnoerlich@fsfe.org")); 
+   text = g_strdup_printf("WWW: [%s]", HOMEPAGE);
+   AboutTextWithLink(vbox, text, HOMEPAGE);
+   g_free(text);
+   
 #ifdef SYS_NETBSD
    AboutText(vbox, _("\nNetBSD port: Sergey Svishchev &lt;svs@ropnet.ru&gt;")); 
 #endif
-#endif
+
    /* Show it */
 
    gtk_widget_show_all(about);
