@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -111,7 +111,7 @@ static void menu_cb(GtkWidget *widget, gpointer data)
 	break;
 
       case MENU_HELP_MANUAL:
-	ShowPDF(NULL);
+	ShowURL(NULL);
 	break;
 
       case MENU_HELP_ABOUT:
