@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -437,7 +437,8 @@ RS02Layout *CalcRS02Layout(Image *image)
       {  case 'r':   /* pick number of roots */
 	 {  char buf[len];
  
-            strncpy(buf, Closure->redundancy, len-1);
+            memcpy(buf, Closure->redundancy, len-1);
+	    buf[len-1]=0;
 	    requested_roots = atoi(buf);
 	    break;
 	 }
@@ -445,7 +446,8 @@ RS02Layout *CalcRS02Layout(Image *image)
 	 {  char buf[len];
 	    int percent;
  
-            strncpy(buf, Closure->redundancy, len-1);
+            memcpy(buf, Closure->redundancy, len-1);
+	    buf[len-1]=0;
 	    percent = atoi(buf);
 
 	    for(requested_roots = 7; requested_roots < 171; requested_roots++)
