@@ -1,8 +1,8 @@
 /*  dvdisaster: Additional error correction for optical media.
  *  Copyright (C) 2004-2017 Carsten Gnoerlich.
+ *  Copyright (C) 2019-2021 The dvdisaster development team.
  *
- *  Email: carsten@dvdisaster.org  -or-  cgnoerlich@fsfe.org
- *  Project homepage: http://www.dvdisaster.org
+ *  Email: support@dvdisaster.org
  *
  *  This file is part of dvdisaster.
  *
@@ -817,7 +817,7 @@ void RS03Verify(Image *image)
    else 
    {  PrintLog(_("* requires         : dvdisaster-%s (BAD)\n"
 		 "* Warning          : The following output might be incorrect.\n"
-		 "*                  : Please visit http://www.dvdisaster.org for an upgrade.\n"),
+		 "*                  : Please upgrade dvdisaster.\n"),
 	       version);
 
      if(Closure->guiMode)
